from colav_protobuf import MissionRequest

# Mock mission request proto message
mission_request = MissionRequest()

# Mission metadata
mission_request.tag = "COLAV_MISSION_NORTH_BELFAST_TO_SOUTH_FRANCE"
mission_request.stamp.sec = int(102341243)  # UNIX timestamp (epoch time in seconds)
mission_request.stamp.nanosec = int(1001230124)  # Nanoseconds

# Static Vessel Information
mission_request.vessel.tag = "EF12_WORKBOAT"
mission_request.vessel.type = MissionRequest.Vessel.VesselType.HYDROFOIL
mission_request.vessel.constraints.max_acceleration = 2.0
mission_request.vessel.constraints.max_deceleration = -1.0
mission_request.vessel.constraints.max_velocity = 30.0
mission_request.vessel.constraints.min_velocity = 15.0
mission_request.vessel.constraints.max_yaw_rate = 0.2
mission_request.vessel.geometry.safety_radius = 5
mission_request.vessel.geometry.loa = 12.0
mission_request.vessel.geometry.beam = 4.0

# Earth-Centered, Earth-Fixed Cartesian Coordinates North Belfast Lough in meters
mission_request.init_position.x = float(3675900.74)
mission_request.init_position.y = float(-372412.13)
mission_request.init_position.z = float(5181577.70)

# Earth-Centered, Earth-Fixed Cartesian Coordinates South France near Marseille in meters
# WON'T USE THIS METRIC IN LOCAL MOTION PLANNER! GOOD FOR GLOBAL PLANNING
mission_request.goal_waypoints.add()
mission_request.goal_waypoints[0].position.x = float(4680627.4)
mission_request.goal_waypoints[0].position.z = float(503374.5)
mission_request.goal_waypoints[0].position.y = float(4299351.3)

# Acceptance radius in meters of the goal waypoint for autonomous navigation.
mission_request.goal_waypoints[0].acceptance_radius = float(7.0)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionResponse.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionResponse.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15missionResponse.proto\x12\x05\x63olav\"\x80\x03\n\x0fMissionResponse\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12+\n\x05stamp\x18\x02 \x01(\x0b\x32\x1c.colav.MissionResponse.Stamp\x12;\n\x08response\x18\x03 \x01(\x0b\x32).colav.MissionResponse.MissionResponseMsg\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\x1a\xce\x01\n\x12MissionResponseMsg\x12H\n\x04type\x18\x01 \x01(\x0e\x32:.colav.MissionResponse.MissionResponseMsg.ResponseTypeEnum\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\"]\n\x10ResponseTypeEnum\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10MISSION_STARTING\x10\x01\x12\x11\n\rMISSION_ERROR\x10\x02\x12\x13\n\x0fMISSION_INVALID\x10\x03\x62\x06proto3'
)



_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM = _descriptor.EnumDescriptor(
  name='ResponseTypeEnum',
  full_name='colav.MissionResponse.MissionResponseMsg.ResponseTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_STARTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=324,
  serialized_end=417,
)
_sym_db.RegisterEnumDescriptor(_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM)


_MISSIONRESPONSE_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.MissionResponse.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.MissionResponse.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.MissionResponse.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=208,
)

_MISSIONRESPONSE_MISSIONRESPONSEMSG = _descriptor.Descriptor(
  name='MissionResponseMsg',
  full_name='colav.MissionResponse.MissionResponseMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.MissionResponse.MissionResponseMsg.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='colav.MissionResponse.MissionResponseMsg.details', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=417,
)

_MISSIONRESPONSE = _descriptor.Descriptor(
  name='MissionResponse',
  full_name='colav.MissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionResponse.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.MissionResponse.stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='colav.MissionResponse.response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONRESPONSE_STAMP, _MISSIONRESPONSE_MISSIONRESPONSEMSG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=417,
)

_MISSIONRESPONSE_STAMP.containing_type = _MISSIONRESPONSE
_MISSIONRESPONSE_MISSIONRESPONSEMSG.fields_by_name['type'].enum_type = _MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM
_MISSIONRESPONSE_MISSIONRESPONSEMSG.containing_type = _MISSIONRESPONSE
_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM.containing_type = _MISSIONRESPONSE_MISSIONRESPONSEMSG
_MISSIONRESPONSE.fields_by_name['stamp'].message_type = _MISSIONRESPONSE_STAMP
_MISSIONRESPONSE.fields_by_name['response'].message_type = _MISSIONRESPONSE_MISSIONRESPONSEMSG
DESCRIPTOR.message_types_by_name['MissionResponse'] = _MISSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionResponse = _reflection.GeneratedProtocolMessageType('MissionResponse', (_message.Message,), {

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONRESPONSE_STAMP,
    '__module__' : 'missionResponse_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionResponse.Stamp)
    })
  ,

  'MissionResponseMsg' : _reflection.GeneratedProtocolMessageType('MissionResponseMsg', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONRESPONSE_MISSIONRESPONSEMSG,
    '__module__' : 'missionResponse_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionResponse.MissionResponseMsg)
    })
  ,
  'DESCRIPTOR' : _MISSIONRESPONSE,
  '__module__' : 'missionResponse_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionResponse)
  })
_sym_db.RegisterMessage(MissionResponse)
_sym_db.RegisterMessage(MissionResponse.Stamp)
_sym_db.RegisterMessage(MissionResponse.MissionResponseMsg)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: obstaclesUpdate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='obstaclesUpdate.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15obstaclesUpdate.proto\x12\x05\x63olav\"\xf5\t\n\x0fObstaclesUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x01(\t\x12\x41\n\x11\x64ynamic_obstacles\x18\x02 \x03(\x0b\x32&.colav.ObstaclesUpdate.DynamicObstacle\x12?\n\x10static_obstacles\x18\x03 \x03(\x0b\x32%.colav.ObstaclesUpdate.StaticObstacle\x12+\n\x05stamp\x18\x04 \x01(\x0b\x32\x1c.colav.ObstaclesUpdate.Stamp\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\x38\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02\x1an\n\x04Pose\x12.\n\x08position\x18\x01 \x01(\x0b\x32\x1c.colav.ObstaclesUpdate.Point\x12\x36\n\x0borientation\x18\x02 \x01(\x0b\x32!.colav.ObstaclesUpdate.Quaternion\x1aV\n\x05State\x12)\n\x04pose\x18\x01 \x01(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x01(\x02\x1aK\n\x17\x44ynamicObstacleGeometry\x12\x0b\n\x03loa\x18\x01 \x01(\x02\x12\x0c\n\x04\x62\x65\x61m\x18\x02 \x01(\x02\x12\x15\n\rsafety_radius\x18\x03 \x01(\x02\x1aj\n\x16StaticObstacleGeometry\x12\x36\n\x10polyshape_points\x18\x01 \x03(\x0b\x32\x1c.colav.ObstaclesUpdate.Point\x12\x18\n\x10inflation_radius\x18\x02 \x01(\x02\x1a\xc7\x01\n\x0f\x44ynamicObstacle\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.colav.ObstaclesUpdate.DynamicObstacleType\x12+\n\x05state\x18\x03 \x01(\x0b\x32\x1c.colav.ObstaclesUpdate.State\x12@\n\x08geometry\x18\x04 \x01(\x0b\x32..colav.ObstaclesUpdate.DynamicObstacleGeometry\x1a\xc2\x01\n\x0eStaticObstacle\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).colav.ObstaclesUpdate.StaticObstacleType\x12)\n\x04pose\x18\x03 \x01(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12?\n\x08geometry\x18\x04 \x01(\x0b\x32-.colav.ObstaclesUpdate.StaticObstacleGeometry\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\":\n\x13\x44ynamicObstacleType\x12\x17\n\x13\x44YNAMIC_UNSPECIFIED\x10\x00\x12\n\n\x06VESSEL\x10\x01\"E\n\x12StaticObstacleType\x12\x16\n\x12STATIC_UNSPECIFIED\x10\x00\x12\r\n\tLAND_MASS\x10\x01\x12\x08\n\x04\x42UOY\x10\x02\x62\x06proto3'
)



_OBSTACLESUPDATE_DYNAMICOBSTACLETYPE = _descriptor.EnumDescriptor(
  name='DynamicObstacleType',
  full_name='colav.ObstaclesUpdate.DynamicObstacleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VESSEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1173,
  serialized_end=1231,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLESUPDATE_DYNAMICOBSTACLETYPE)

_OBSTACLESUPDATE_STATICOBSTACLETYPE = _descriptor.EnumDescriptor(
  name='StaticObstacleType',
  full_name='colav.ObstaclesUpdate.StaticObstacleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATIC_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAND_MASS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUOY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1233,
  serialized_end=1302,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLESUPDATE_STATICOBSTACLETYPE)


_OBSTACLESUPDATE_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.ObstaclesUpdate.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.ObstaclesUpdate.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.ObstaclesUpdate.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.ObstaclesUpdate.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=290,
)

_OBSTACLESUPDATE_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='colav.ObstaclesUpdate.Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.ObstaclesUpdate.Quaternion.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.ObstaclesUpdate.Quaternion.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.ObstaclesUpdate.Quaternion.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='colav.ObstaclesUpdate.Quaternion.w', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=348,
)

_OBSTACLESUPDATE_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='colav.ObstaclesUpdate.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='colav.ObstaclesUpdate.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='colav.ObstaclesUpdate.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=460,
)

_OBSTACLESUPDATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='colav.ObstaclesUpdate.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='colav.ObstaclesUpdate.State.pose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='colav.ObstaclesUpdate.State.velocity', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='colav.ObstaclesUpdate.State.yaw_rate', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=548,
)

_OBSTACLESUPDATE_DYNAMICOBSTACLEGEOMETRY = _descriptor.Descriptor(
  name='DynamicObstacleGeometry',
  full_name='colav.ObstaclesUpdate.DynamicObstacleGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loa', full_name='colav.ObstaclesUpdate.DynamicObstacleGeometry.loa', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beam', full_name='colav.ObstaclesUpdate.DynamicObstacleGeometry.beam', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safety_radius', full_name='colav.ObstaclesUpdate.DynamicObstacleGeometry.safety_radius', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=625,
)

_OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY = _descriptor.Descriptor(
  name='StaticObstacleGeometry',
  full_name='colav.ObstaclesUpdate.StaticObstacleGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='polyshape_points', full_name='colav.ObstaclesUpdate.StaticObstacleGeometry.polyshape_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inflation_radius', full_name='colav.ObstaclesUpdate.StaticObstacleGeometry.inflation_radius', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=733,
)

_OBSTACLESUPDATE_DYNAMICOBSTACLE = _descriptor.Descriptor(
  name='DynamicObstacle',
  full_name='colav.ObstaclesUpdate.DynamicObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.ObstaclesUpdate.DynamicObstacle.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.ObstaclesUpdate.DynamicObstacle.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='colav.ObstaclesUpdate.DynamicObstacle.state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.ObstaclesUpdate.DynamicObstacle.geometry', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=935,
)

_OBSTACLESUPDATE_STATICOBSTACLE = _descriptor.Descriptor(
  name='StaticObstacle',
  full_name='colav.ObstaclesUpdate.StaticObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.ObstaclesUpdate.StaticObstacle.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.ObstaclesUpdate.StaticObstacle.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='colav.ObstaclesUpdate.StaticObstacle.pose', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.ObstaclesUpdate.StaticObstacle.geometry', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1132,
)

_OBSTACLESUPDATE_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.ObstaclesUpdate.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.ObstaclesUpdate.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.ObstaclesUpdate.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1171,
)

_OBSTACLESUPDATE = _descriptor.Descriptor(
  name='ObstaclesUpdate',
  full_name='colav.ObstaclesUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.ObstaclesUpdate.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_obstacles', full_name='colav.ObstaclesUpdate.dynamic_obstacles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_obstacles', full_name='colav.ObstaclesUpdate.static_obstacles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.ObstaclesUpdate.stamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSTACLESUPDATE_POINT, _OBSTACLESUPDATE_QUATERNION, _OBSTACLESUPDATE_POSE, _OBSTACLESUPDATE_STATE, _OBSTACLESUPDATE_DYNAMICOBSTACLEGEOMETRY, _OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY, _OBSTACLESUPDATE_DYNAMICOBSTACLE, _OBSTACLESUPDATE_STATICOBSTACLE, _OBSTACLESUPDATE_STAMP, ],
  enum_types=[
    _OBSTACLESUPDATE_DYNAMICOBSTACLETYPE,
    _OBSTACLESUPDATE_STATICOBSTACLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=1302,
)

_OBSTACLESUPDATE_POINT.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_QUATERNION.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_POSE.fields_by_name['position'].message_type = _OBSTACLESUPDATE_POINT
_OBSTACLESUPDATE_POSE.fields_by_name['orientation'].message_type = _OBSTACLESUPDATE_QUATERNION
_OBSTACLESUPDATE_POSE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATE.fields_by_name['pose'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_STATE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_DYNAMICOBSTACLEGEOMETRY.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY.fields_by_name['polyshape_points'].message_type = _OBSTACLESUPDATE_POINT
_OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['type'].enum_type = _OBSTACLESUPDATE_DYNAMICOBSTACLETYPE
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['state'].message_type = _OBSTACLESUPDATE_STATE
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['geometry'].message_type = _OBSTACLESUPDATE_DYNAMICOBSTACLEGEOMETRY
_OBSTACLESUPDATE_DYNAMICOBSTACLE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['type'].enum_type = _OBSTACLESUPDATE_STATICOBSTACLETYPE
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['pose'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['geometry'].message_type = _OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY
_OBSTACLESUPDATE_STATICOBSTACLE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STAMP.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE.fields_by_name['dynamic_obstacles'].message_type = _OBSTACLESUPDATE_DYNAMICOBSTACLE
_OBSTACLESUPDATE.fields_by_name['static_obstacles'].message_type = _OBSTACLESUPDATE_STATICOBSTACLE
_OBSTACLESUPDATE.fields_by_name['stamp'].message_type = _OBSTACLESUPDATE_STAMP
_OBSTACLESUPDATE_DYNAMICOBSTACLETYPE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATICOBSTACLETYPE.containing_type = _OBSTACLESUPDATE
DESCRIPTOR.message_types_by_name['ObstaclesUpdate'] = _OBSTACLESUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObstaclesUpdate = _reflection.GeneratedProtocolMessageType('ObstaclesUpdate', (_message.Message,), {

  'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_POINT,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Point)
    })
  ,

  'Quaternion' : _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_QUATERNION,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Quaternion)
    })
  ,

  'Pose' : _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_POSE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Pose)
    })
  ,

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STATE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.State)
    })
  ,

  'DynamicObstacleGeometry' : _reflection.GeneratedProtocolMessageType('DynamicObstacleGeometry', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_DYNAMICOBSTACLEGEOMETRY,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.DynamicObstacleGeometry)
    })
  ,

  'StaticObstacleGeometry' : _reflection.GeneratedProtocolMessageType('StaticObstacleGeometry', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STATICOBSTACLEGEOMETRY,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.StaticObstacleGeometry)
    })
  ,

  'DynamicObstacle' : _reflection.GeneratedProtocolMessageType('DynamicObstacle', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_DYNAMICOBSTACLE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.DynamicObstacle)
    })
  ,

  'StaticObstacle' : _reflection.GeneratedProtocolMessageType('StaticObstacle', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STATICOBSTACLE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.StaticObstacle)
    })
  ,

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STAMP,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Stamp)
    })
  ,
  'DESCRIPTOR' : _OBSTACLESUPDATE,
  '__module__' : 'obstaclesUpdate_pb2'
  # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate)
  })
_sym_db.RegisterMessage(ObstaclesUpdate)
_sym_db.RegisterMessage(ObstaclesUpdate.Point)
_sym_db.RegisterMessage(ObstaclesUpdate.Quaternion)
_sym_db.RegisterMessage(ObstaclesUpdate.Pose)
_sym_db.RegisterMessage(ObstaclesUpdate.State)
_sym_db.RegisterMessage(ObstaclesUpdate.DynamicObstacleGeometry)
_sym_db.RegisterMessage(ObstaclesUpdate.StaticObstacleGeometry)
_sym_db.RegisterMessage(ObstaclesUpdate.DynamicObstacle)
_sym_db.RegisterMessage(ObstaclesUpdate.StaticObstacle)
_sym_db.RegisterMessage(ObstaclesUpdate.Stamp)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: unsafeSet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="unsafeSet.proto",
    package="colav",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0funsafeSet.proto\x12\x05\x63olav"\xcc\x01\n\tUnsafeSet\x12%\n\x05stamp\x18\x01 \x01(\x0b\x32\x16.colav.UnsafeSet.Stamp\x12\x13\n\x0bmission_tag\x18\x02 \x01(\t\x12-\n\x08vertices\x18\x03 \x03(\x0b\x32\x1b.colav.UnsafeSet.Coordinate\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\x1a-\n\nCoordinate\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x62\x06proto3',
)


_UNSAFESET_STAMP = _descriptor.Descriptor(
    name="Stamp",
    full_name="colav.UnsafeSet.Stamp",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="sec",
            full_name="colav.UnsafeSet.Stamp.sec",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="nanosec",
            full_name="colav.UnsafeSet.Stamp.nanosec",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=147,
    serialized_end=184,
)

_UNSAFESET_COORDINATE = _descriptor.Descriptor(
    name="Coordinate",
    full_name="colav.UnsafeSet.Coordinate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="x",
            full_name="colav.UnsafeSet.Coordinate.x",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="y",
            full_name="colav.UnsafeSet.Coordinate.y",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="z",
            full_name="colav.UnsafeSet.Coordinate.z",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=186,
    serialized_end=231,
)

_UNSAFESET = _descriptor.Descriptor(
    name="UnsafeSet",
    full_name="colav.UnsafeSet",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="stamp",
            full_name="colav.UnsafeSet.stamp",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mission_tag",
            full_name="colav.UnsafeSet.mission_tag",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="vertices",
            full_name="colav.UnsafeSet.vertices",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _UNSAFESET_STAMP,
        _UNSAFESET_COORDINATE,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=27,
    serialized_end=231,
)

_UNSAFESET_STAMP.containing_type = _UNSAFESET
_UNSAFESET_COORDINATE.containing_type = _UNSAFESET
_UNSAFESET.fields_by_name["stamp"].message_type = _UNSAFESET_STAMP
_UNSAFESET.fields_by_name["vertices"].message_type = _UNSAFESET_COORDINATE
DESCRIPTOR.message_types_by_name["UnsafeSet"] = _UNSAFESET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnsafeSet = _reflection.GeneratedProtocolMessageType(
    "UnsafeSet",
    (_message.Message,),
    {
        "Stamp": _reflection.GeneratedProtocolMessageType(
            "Stamp",
            (_message.Message,),
            {
                "DESCRIPTOR": _UNSAFESET_STAMP,
                "__module__": "unsafeSet_pb2",
                # @@protoc_insertion_point(class_scope:colav.UnsafeSet.Stamp)
            },
        ),
        "Coordinate": _reflection.GeneratedProtocolMessageType(
            "Coordinate",
            (_message.Message,),
            {
                "DESCRIPTOR": _UNSAFESET_COORDINATE,
                "__module__": "unsafeSet_pb2",
                # @@protoc_insertion_point(class_scope:colav.UnsafeSet.Coordinate)
            },
        ),
        "DESCRIPTOR": _UNSAFESET,
        "__module__": "unsafeSet_pb2",
        # @@protoc_insertion_point(class_scope:colav.UnsafeSet)
    },
)
_sym_db.RegisterMessage(UnsafeSet)
_sym_db.RegisterMessage(UnsafeSet.Stamp)
_sym_db.RegisterMessage(UnsafeSet.Coordinate)


# @@protoc_insertion_point(module_scope)



from colav_protobuf.missionRequest_pb2 import MissionRequest
from colav_protobuf.missionResponse_pb2 import MissionResponse
from colav_protobuf.agentUpdate_pb2 import AgentUpdate
from colav_protobuf.obstaclesUpdate_pb2 import ObstaclesUpdate
from colav_protobuf.controllerFeedback_pb2 import ControllerFeedback
from colav_protobuf.unsafeSet_pb2 import UnsafeSet

__all__ = [
    "MissionRequest",
    "MissionResponse",
    "AgentUpdate",
    "ObstaclesUpdate",
    "ControllerFeedback",
    "UnsafeSet",
]



from colav_protobuf import UnsafeSet

# Mock an unsafe set proto message
unsafe_set = UnsafeSet()
unsafe_set.mission_tag = "COLAV_MISSION_NORTH_BELFAST_TO_SOUTH_FRANCE"
unsafe_set.stamp.sec = 1234
unsafe_set.stamp.nanosec = 1235

# Define meaningful polygon coordinates (example: a simple rectangle)
coordinates = [(10, 5), (15, 5), (15, 10), (10, 10)]

# Add coordinates to the proto message
for x, y in coordinates:
    coord = unsafe_set.vertices.add()
    coord.x = x
    coord.y = y
    coord.z = 0


from colav_protobuf.examples.mission_request import mission_request
from colav_protobuf.examples.mission_response import mission_response

from colav_protobuf.examples.agent_update import agent_update
from colav_protobuf.examples.obstacles_update import obstacles_update

from colav_protobuf.examples.controller_feedback import controller_feedback

from colav_protobuf.examples.unsafe_set import unsafe_set

__all__ = [
    "mission_request",
    "mission_response",
    "agent_update",
    "obstacles_update",
    "controller_feedback",
    "unsafe_set"
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: controllerFeedback.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='controllerFeedback.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x63ontrollerFeedback.proto\x12\x05\x63olav\"\x80\x04\n\x12\x43ontrollerFeedback\x12\x13\n\x0bmission_tag\x18\x01 \x01(\t\x12\x11\n\tagent_tag\x18\x02 \x01(\t\x12\x30\n\x04mode\x18\x03 \x01(\x0e\x32\".colav.ControllerFeedback.CtrlMode\x12\x34\n\x06status\x18\x04 \x01(\x0e\x32$.colav.ControllerFeedback.CtrlStatus\x12\x30\n\x03\x63md\x18\x05 \x01(\x0b\x32#.colav.ControllerFeedback.CmdVelYaw\x12.\n\x05stamp\x18\x06 \x01(\x0b\x32\x1f.colav.ControllerFeedback.Stamp\x1a/\n\tCmdVelYaw\x12\x10\n\x08velocity\x18\x01 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x02 \x01(\x02\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\"Y\n\x08\x43trlMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x43RUISE\x10\x01\x12\t\n\x05T2LOS\x10\x02\x12\x0b\n\x07T2Theta\x10\x03\x12\x06\n\x02\x46\x42\x10\x04\x12\x14\n\x10WAYPOINT_REACHED\x10\x05\"E\n\nCtrlStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x62\x06proto3'
)



_CONTROLLERFEEDBACK_CTRLMODE = _descriptor.EnumDescriptor(
  name='CtrlMode',
  full_name='colav.ControllerFeedback.CtrlMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='T2LOS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='T2Theta', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FB', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAYPOINT_REACHED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=388,
  serialized_end=477,
)
_sym_db.RegisterEnumDescriptor(_CONTROLLERFEEDBACK_CTRLMODE)

_CONTROLLERFEEDBACK_CTRLSTATUS = _descriptor.EnumDescriptor(
  name='CtrlStatus',
  full_name='colav.ControllerFeedback.CtrlStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_STATUS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=479,
  serialized_end=548,
)
_sym_db.RegisterEnumDescriptor(_CONTROLLERFEEDBACK_CTRLSTATUS)


_CONTROLLERFEEDBACK_CMDVELYAW = _descriptor.Descriptor(
  name='CmdVelYaw',
  full_name='colav.ControllerFeedback.CmdVelYaw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='velocity', full_name='colav.ControllerFeedback.CmdVelYaw.velocity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='colav.ControllerFeedback.CmdVelYaw.yaw_rate', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=347,
)

_CONTROLLERFEEDBACK_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.ControllerFeedback.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.ControllerFeedback.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.ControllerFeedback.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=386,
)

_CONTROLLERFEEDBACK = _descriptor.Descriptor(
  name='ControllerFeedback',
  full_name='colav.ControllerFeedback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.ControllerFeedback.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_tag', full_name='colav.ControllerFeedback.agent_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='colav.ControllerFeedback.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='colav.ControllerFeedback.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='colav.ControllerFeedback.cmd', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.ControllerFeedback.stamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONTROLLERFEEDBACK_CMDVELYAW, _CONTROLLERFEEDBACK_STAMP, ],
  enum_types=[
    _CONTROLLERFEEDBACK_CTRLMODE,
    _CONTROLLERFEEDBACK_CTRLSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=548,
)

_CONTROLLERFEEDBACK_CMDVELYAW.containing_type = _CONTROLLERFEEDBACK
_CONTROLLERFEEDBACK_STAMP.containing_type = _CONTROLLERFEEDBACK
_CONTROLLERFEEDBACK.fields_by_name['mode'].enum_type = _CONTROLLERFEEDBACK_CTRLMODE
_CONTROLLERFEEDBACK.fields_by_name['status'].enum_type = _CONTROLLERFEEDBACK_CTRLSTATUS
_CONTROLLERFEEDBACK.fields_by_name['cmd'].message_type = _CONTROLLERFEEDBACK_CMDVELYAW
_CONTROLLERFEEDBACK.fields_by_name['stamp'].message_type = _CONTROLLERFEEDBACK_STAMP
_CONTROLLERFEEDBACK_CTRLMODE.containing_type = _CONTROLLERFEEDBACK
_CONTROLLERFEEDBACK_CTRLSTATUS.containing_type = _CONTROLLERFEEDBACK
DESCRIPTOR.message_types_by_name['ControllerFeedback'] = _CONTROLLERFEEDBACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControllerFeedback = _reflection.GeneratedProtocolMessageType('ControllerFeedback', (_message.Message,), {

  'CmdVelYaw' : _reflection.GeneratedProtocolMessageType('CmdVelYaw', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERFEEDBACK_CMDVELYAW,
    '__module__' : 'controllerFeedback_pb2'
    # @@protoc_insertion_point(class_scope:colav.ControllerFeedback.CmdVelYaw)
    })
  ,

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERFEEDBACK_STAMP,
    '__module__' : 'controllerFeedback_pb2'
    # @@protoc_insertion_point(class_scope:colav.ControllerFeedback.Stamp)
    })
  ,
  'DESCRIPTOR' : _CONTROLLERFEEDBACK,
  '__module__' : 'controllerFeedback_pb2'
  # @@protoc_insertion_point(class_scope:colav.ControllerFeedback)
  })
_sym_db.RegisterMessage(ControllerFeedback)
_sym_db.RegisterMessage(ControllerFeedback.CmdVelYaw)
_sym_db.RegisterMessage(ControllerFeedback.Stamp)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionRequest.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionRequest.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14missionRequest.proto\x12\x05\x63olav\"\xee\x06\n\x0eMissionRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12*\n\x05stamp\x18\x02 \x01(\x0b\x32\x1b.colav.MissionRequest.Stamp\x12,\n\x06vessel\x18\x03 \x01(\x0b\x32\x1c.colav.MissionRequest.Vessel\x12\x32\n\rinit_position\x18\x04 \x01(\x0b\x32\x1b.colav.MissionRequest.Point\x12:\n\x0egoal_waypoints\x18\x05 \x03(\x0b\x32\".colav.MissionRequest.GoalWaypoint\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\xd9\x03\n\x06Vessel\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x35\n\x04type\x18\x02 \x01(\x0e\x32\'.colav.MissionRequest.Vessel.VesselType\x12\x43\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32..colav.MissionRequest.Vessel.VesselConstraints\x12=\n\x08geometry\x18\x04 \x01(\x0b\x32+.colav.MissionRequest.Vessel.VesselGeometry\x1a\x89\x01\n\x11VesselConstraints\x12\x18\n\x10max_acceleration\x18\x03 \x01(\x02\x12\x18\n\x10max_deceleration\x18\x04 \x01(\x02\x12\x14\n\x0cmax_velocity\x18\x05 \x01(\x02\x12\x14\n\x0cmin_velocity\x18\x06 \x01(\x02\x12\x14\n\x0cmax_yaw_rate\x18\x07 \x01(\x02\x1a\x42\n\x0eVesselGeometry\x12\x0b\n\x03loa\x18\x01 \x01(\x02\x12\x0c\n\x04\x62\x65\x61m\x18\x02 \x01(\x02\x12\x15\n\rsafety_radius\x18\x03 \x01(\x02\"7\n\nVesselType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tHYDROFOIL\x10\x01\x12\t\n\x05OTHER\x10\x02\x1aX\n\x0cGoalWaypoint\x12-\n\x08position\x18\x01 \x01(\x0b\x32\x1b.colav.MissionRequest.Point\x12\x19\n\x11\x61\x63\x63\x65ptance_radius\x18\x02 \x01(\x02\x62\x06proto3'
)



_MISSIONREQUEST_VESSEL_VESSELTYPE = _descriptor.EnumDescriptor(
  name='VesselType',
  full_name='colav.MissionRequest.Vessel.VesselType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYDROFOIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=765,
  serialized_end=820,
)
_sym_db.RegisterEnumDescriptor(_MISSIONREQUEST_VESSEL_VESSELTYPE)


_MISSIONREQUEST_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.MissionRequest.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.MissionRequest.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.MissionRequest.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=302,
)

_MISSIONREQUEST_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.MissionRequest.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.MissionRequest.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.MissionRequest.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.MissionRequest.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=344,
)

_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS = _descriptor.Descriptor(
  name='VesselConstraints',
  full_name='colav.MissionRequest.Vessel.VesselConstraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_acceleration', index=0,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_deceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_deceleration', index=1,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_velocity', index=2,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.min_velocity', index=3,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_yaw_rate', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_yaw_rate', index=4,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=695,
)

_MISSIONREQUEST_VESSEL_VESSELGEOMETRY = _descriptor.Descriptor(
  name='VesselGeometry',
  full_name='colav.MissionRequest.Vessel.VesselGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loa', full_name='colav.MissionRequest.Vessel.VesselGeometry.loa', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beam', full_name='colav.MissionRequest.Vessel.VesselGeometry.beam', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safety_radius', full_name='colav.MissionRequest.Vessel.VesselGeometry.safety_radius', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=763,
)

_MISSIONREQUEST_VESSEL = _descriptor.Descriptor(
  name='Vessel',
  full_name='colav.MissionRequest.Vessel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.Vessel.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.MissionRequest.Vessel.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='colav.MissionRequest.Vessel.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.MissionRequest.Vessel.geometry', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS, _MISSIONREQUEST_VESSEL_VESSELGEOMETRY, ],
  enum_types=[
    _MISSIONREQUEST_VESSEL_VESSELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=820,
)

_MISSIONREQUEST_GOALWAYPOINT = _descriptor.Descriptor(
  name='GoalWaypoint',
  full_name='colav.MissionRequest.GoalWaypoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='colav.MissionRequest.GoalWaypoint.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptance_radius', full_name='colav.MissionRequest.GoalWaypoint.acceptance_radius', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=910,
)

_MISSIONREQUEST = _descriptor.Descriptor(
  name='MissionRequest',
  full_name='colav.MissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.MissionRequest.stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel', full_name='colav.MissionRequest.vessel', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_position', full_name='colav.MissionRequest.init_position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_waypoints', full_name='colav.MissionRequest.goal_waypoints', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_STAMP, _MISSIONREQUEST_POINT, _MISSIONREQUEST_VESSEL, _MISSIONREQUEST_GOALWAYPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=910,
)

_MISSIONREQUEST_STAMP.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_POINT.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL_VESSELGEOMETRY.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL.fields_by_name['type'].enum_type = _MISSIONREQUEST_VESSEL_VESSELTYPE
_MISSIONREQUEST_VESSEL.fields_by_name['constraints'].message_type = _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS
_MISSIONREQUEST_VESSEL.fields_by_name['geometry'].message_type = _MISSIONREQUEST_VESSEL_VESSELGEOMETRY
_MISSIONREQUEST_VESSEL.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELTYPE.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_GOALWAYPOINT.fields_by_name['position'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST_GOALWAYPOINT.containing_type = _MISSIONREQUEST
_MISSIONREQUEST.fields_by_name['stamp'].message_type = _MISSIONREQUEST_STAMP
_MISSIONREQUEST.fields_by_name['vessel'].message_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST.fields_by_name['init_position'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST.fields_by_name['goal_waypoints'].message_type = _MISSIONREQUEST_GOALWAYPOINT
DESCRIPTOR.message_types_by_name['MissionRequest'] = _MISSIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionRequest = _reflection.GeneratedProtocolMessageType('MissionRequest', (_message.Message,), {

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_STAMP,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Stamp)
    })
  ,

  'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_POINT,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Point)
    })
  ,

  'Vessel' : _reflection.GeneratedProtocolMessageType('Vessel', (_message.Message,), {

    'VesselConstraints' : _reflection.GeneratedProtocolMessageType('VesselConstraints', (_message.Message,), {
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselConstraints)
      })
    ,

    'VesselGeometry' : _reflection.GeneratedProtocolMessageType('VesselGeometry', (_message.Message,), {
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELGEOMETRY,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselGeometry)
      })
    ,
    'DESCRIPTOR' : _MISSIONREQUEST_VESSEL,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel)
    })
  ,

  'GoalWaypoint' : _reflection.GeneratedProtocolMessageType('GoalWaypoint', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_GOALWAYPOINT,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.GoalWaypoint)
    })
  ,
  'DESCRIPTOR' : _MISSIONREQUEST,
  '__module__' : 'missionRequest_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionRequest)
  })
_sym_db.RegisterMessage(MissionRequest)
_sym_db.RegisterMessage(MissionRequest.Stamp)
_sym_db.RegisterMessage(MissionRequest.Point)
_sym_db.RegisterMessage(MissionRequest.Vessel)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselConstraints)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselGeometry)
_sym_db.RegisterMessage(MissionRequest.GoalWaypoint)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agentUpdate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='agentUpdate.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x61gentUpdate.proto\x12\x05\x63olav\"\xf7\x03\n\x0b\x41gentUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x01(\t\x12\x11\n\tagent_tag\x18\x02 \x01(\t\x12\'\n\x05state\x18\x03 \x01(\x0b\x32\x18.colav.AgentUpdate.State\x12\'\n\x05stamp\x18\x04 \x01(\x0b\x32\x18.colav.AgentUpdate.Stamp\x1a\xdc\x01\n\x04Pose\x12\x32\n\x08position\x18\x01 \x01(\x0b\x32 .colav.AgentUpdate.Pose.Position\x12\x38\n\x0borientation\x18\x02 \x01(\x0b\x32#.colav.AgentUpdate.Pose.Orientation\x1a+\n\x08Position\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\x39\n\x0bOrientation\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02\x1ah\n\x05State\x12%\n\x04pose\x18\x01 \x01(\x0b\x32\x17.colav.AgentUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x01(\x02\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x02\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\rb\x06proto3'
)




_AGENTUPDATE_POSE_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='colav.AgentUpdate.Pose.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.AgentUpdate.Pose.Position.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.AgentUpdate.Pose.Position.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.AgentUpdate.Pose.Position.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=328,
)

_AGENTUPDATE_POSE_ORIENTATION = _descriptor.Descriptor(
  name='Orientation',
  full_name='colav.AgentUpdate.Pose.Orientation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.AgentUpdate.Pose.Orientation.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.AgentUpdate.Pose.Orientation.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.AgentUpdate.Pose.Orientation.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='colav.AgentUpdate.Pose.Orientation.w', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=387,
)

_AGENTUPDATE_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='colav.AgentUpdate.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='colav.AgentUpdate.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='colav.AgentUpdate.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AGENTUPDATE_POSE_POSITION, _AGENTUPDATE_POSE_ORIENTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=387,
)

_AGENTUPDATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='colav.AgentUpdate.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='colav.AgentUpdate.State.pose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='colav.AgentUpdate.State.velocity', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='colav.AgentUpdate.State.yaw_rate', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='colav.AgentUpdate.State.acceleration', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=493,
)

_AGENTUPDATE_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.AgentUpdate.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.AgentUpdate.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.AgentUpdate.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=495,
  serialized_end=532,
)

_AGENTUPDATE = _descriptor.Descriptor(
  name='AgentUpdate',
  full_name='colav.AgentUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.AgentUpdate.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_tag', full_name='colav.AgentUpdate.agent_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='colav.AgentUpdate.state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.AgentUpdate.stamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AGENTUPDATE_POSE, _AGENTUPDATE_STATE, _AGENTUPDATE_STAMP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=532,
)

_AGENTUPDATE_POSE_POSITION.containing_type = _AGENTUPDATE_POSE
_AGENTUPDATE_POSE_ORIENTATION.containing_type = _AGENTUPDATE_POSE
_AGENTUPDATE_POSE.fields_by_name['position'].message_type = _AGENTUPDATE_POSE_POSITION
_AGENTUPDATE_POSE.fields_by_name['orientation'].message_type = _AGENTUPDATE_POSE_ORIENTATION
_AGENTUPDATE_POSE.containing_type = _AGENTUPDATE
_AGENTUPDATE_STATE.fields_by_name['pose'].message_type = _AGENTUPDATE_POSE
_AGENTUPDATE_STATE.containing_type = _AGENTUPDATE
_AGENTUPDATE_STAMP.containing_type = _AGENTUPDATE
_AGENTUPDATE.fields_by_name['state'].message_type = _AGENTUPDATE_STATE
_AGENTUPDATE.fields_by_name['stamp'].message_type = _AGENTUPDATE_STAMP
DESCRIPTOR.message_types_by_name['AgentUpdate'] = _AGENTUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AgentUpdate = _reflection.GeneratedProtocolMessageType('AgentUpdate', (_message.Message,), {

  'Pose' : _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), {

    'Position' : _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
      'DESCRIPTOR' : _AGENTUPDATE_POSE_POSITION,
      '__module__' : 'agentUpdate_pb2'
      # @@protoc_insertion_point(class_scope:colav.AgentUpdate.Pose.Position)
      })
    ,

    'Orientation' : _reflection.GeneratedProtocolMessageType('Orientation', (_message.Message,), {
      'DESCRIPTOR' : _AGENTUPDATE_POSE_ORIENTATION,
      '__module__' : 'agentUpdate_pb2'
      # @@protoc_insertion_point(class_scope:colav.AgentUpdate.Pose.Orientation)
      })
    ,
    'DESCRIPTOR' : _AGENTUPDATE_POSE,
    '__module__' : 'agentUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.AgentUpdate.Pose)
    })
  ,

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _AGENTUPDATE_STATE,
    '__module__' : 'agentUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.AgentUpdate.State)
    })
  ,

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _AGENTUPDATE_STAMP,
    '__module__' : 'agentUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.AgentUpdate.Stamp)
    })
  ,
  'DESCRIPTOR' : _AGENTUPDATE,
  '__module__' : 'agentUpdate_pb2'
  # @@protoc_insertion_point(class_scope:colav.AgentUpdate)
  })
_sym_db.RegisterMessage(AgentUpdate)
_sym_db.RegisterMessage(AgentUpdate.Pose)
_sym_db.RegisterMessage(AgentUpdate.Pose.Position)
_sym_db.RegisterMessage(AgentUpdate.Pose.Orientation)
_sym_db.RegisterMessage(AgentUpdate.State)
_sym_db.RegisterMessage(AgentUpdate.Stamp)


# @@protoc_insertion_point(module_scope)



from colav_protobuf import AgentUpdate

"""mocks a agent update proto message"""
agent_update = AgentUpdate()
agent_update.mission_tag = "COLAV_MISSION_NORTH_BELFAST_TO_SOUTH_FRANCE"
agent_update.agent_tag = "COLAV_AGENT_1"
agent_update.stamp.sec = int(10000231)
agent_update.stamp.nanosec = int(1001230124)
agent_update.state.pose.position.x = float(3_675_830.74)
agent_update.state.pose.position.y = float(-272_412.13)
agent_update.state.pose.position.z = float(4_181_577.70)
agent_update.state.pose.orientation.x = 0
agent_update.state.pose.orientation.y = 0
agent_update.state.pose.orientation.z = 0
agent_update.state.pose.orientation.w = 1

agent_update.state.velocity = 20
agent_update.state.yaw_rate = 0.2
agent_update.state.acceleration = 1
